@@ -1,23 +1,9 @@
-/********************************************************************
- KSld - the KDE Screenlocker Daemon
- This file is part of the KDE project.
+/*
+SPDX-FileCopyrightText: 2004 Chris Howells <howells@kde.org>
+SPDX-FileCopyrightText: 2011 Martin Gräßlin <mgraesslin@kde.org>
 
-Copyright (C) 2004 Chris Howells <howells@kde.org>
-Copyright (C) 2011 Martin Gräßlin <mgraesslin@kde.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "greeterapp.h"
 #include "kscreensaversettingsbase.h"
 #include "lnf_integration.h"
@@ -37,6 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KDeclarative/KQuickAddons/QuickViewSharedEngine>
 #include <KDeclarative/QmlObjectSharedEngine>
 #include <KLocalizedContext>
+#include <KScreenDpms/Dpms>
 #include <KWindowSystem>
 #include <kdeclarative/kdeclarative.h>
 
@@ -268,7 +255,7 @@ KDeclarative::QmlObjectSharedEngine *UnlockApp::loadWallpaperPlugin(KQuickAddons
 
     auto qmlObject = new KDeclarative::QmlObjectSharedEngine(view);
     qmlObject->setInitializationDelayed(true);
-    qmlObject->setPackage(package);
+    qmlObject->setSource(QUrl::fromLocalFile(package.filePath("mainscript")));
     qmlObject->rootContext()->setContextProperty(QStringLiteral("wallpaper"), m_wallpaperIntegration);
     view->setProperty("wallpaperGraphicsObject", QVariant::fromValue(qmlObject));
     connect(qmlObject, &KDeclarative::QmlObject::finished, this, [this, qmlObject, view] {
@@ -607,6 +594,13 @@ bool UnlockApp::eventFilter(QObject *obj, QEvent *event)
         if (ke->key() != Qt::Key_Escape) {
             shareEvent(event, qobject_cast<KQuickAddons::QuickViewSharedEngine *>(obj));
             return false; // irrelevant
+        } else {
+            auto dpms = new KScreen::Dpms(this);
+            connect(dpms, &KScreen::Dpms::supportedChanged, this, [dpms](bool supported) {
+                if (supported) {
+                    dpms->switchMode(KScreen::Dpms::Off);
+                }
+            });
         }
         return true; // don't pass
     }
@@ -715,6 +709,10 @@ void UnlockApp::osdProgress(const QString &icon, int percent, const QString &add
             continue;
         }
         osd->setProperty("osdValue", percent);
+        // HACK: if the value is >100 assume max is 150, to fix https://bugs.kde.org/show_bug.cgi?id=430536
+        // this is because the osdProgress signal does not have a maxPercent parameter
+        // it can't be fixed without breaking the DBus API so TODO KF6
+        osd->setProperty("osdMaxValue", percent > 100 ? 150 : 100);
         osd->setProperty("osdAdditionalText", additionalText);
         osd->setProperty("showingProgress", true);
         osd->setProperty("icon", icon);
